==> ejc-production-impl-3.0.0-20220615.135539-150-sources.jar: com/ejianc/business/production/bean/UnitdistributionEntity.java <==
package com.ejianc.business.production.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 分配机组
 * 
 * @author generator
 * 
 */
 @TableName("ejc_production_unit_distribution")
public class UnitdistributionEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="unit_id")
    private Long unitId; // 机组id
    @TableField(value="unit_name")
    private String unitName; // 机组名称
    @TableField(value="task_id")
    private Long taskId; // 任务单id
    @TableField(value="task_code")
    private String taskCode; // 任务单单号
    @TableField(value="satrt_time")
    private Date satrtTime; // 开始时间
    @TableField(value="end_time")
    private Date endTime; // 结束时间
    @TableField(value="distribute_count")
    private BigDecimal distributeCount; // 分配数量
    @TableField(value="operator_id")
    private Long operatorId; // 经办人id
    @TableField(value="operator_name")
    private String operatorName; // 经办人名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="change_id")
    private Long changeId; // 变更单据id
    @TableField(value="change_state")
    private String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    @TableField(value="product_id")
    private Long productId; // 产品id
    @TableField(value="product_name")
    private String productName; // 产品名称
    @TableField(value="customer_manage_id")
    private Long customerManageId; // 客户管理档案id
    @TableField(value="customer_manage_name")
    private String customerManageName; // 客户管理档案名称
    @TableField(value="project_id")
    private Long projectId; // 工程id
    @TableField(value="project_name")
    private String projectName; // 工程名称
    @TableField(value="worksite_id")
    private Long worksiteId; // 工地id
    @TableField(value="worksite_name")
    private String worksiteName; // 工地名称
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="quantity")
    private BigDecimal quantity; // 数量
    @TableField(value="weigh_number")
    private BigDecimal weighNumber; // 过磅数
    @TableField(value="not_weigh_number")
    private BigDecimal notWeighNumber; // 未过磅数量
    @TableField(value="add_count")
    private BigDecimal addCount; // 追加数量
    @TableField(value="added_count")
    private BigDecimal addedCount; // 追加后数量
    @TableField(value="product_state")
    private Integer productState; // 分配机组生产状态 ：1 生产中 2 生产完成
    @TableField(value="not_distribute_count")
    private BigDecimal notDistributeCount; // 未分配数量
    @TableField(value="distributed_count")
    private BigDecimal distributedCount; // 已分配数量
    @TableField(value="is_distribute_car")
    private Integer isDistributeCar; // 分配车辆状态 ：1 未分配 2 已分配
    @TableField(value="sort")
    private Integer sort; // 分配车辆状态 ：1 未分配 2 已分配
    @TableField(value="producted_count")
    private BigDecimal productedCount; // 已生产数量
    @TableField(value="not_product_count")
    private BigDecimal notProductCount; // 未生产数量

    @TableField(exist=false)
    @SubEntity(serviceName="productiontasktransportService",pidName = "unitdistributeId")
    private List<ProductiontasktransportEntity> taskTransportList = new ArrayList<>(); // 运费维护子表
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public Long getTaskId() {
        return taskId;
    }

    public void setTaskId(Long taskId) {
        this.taskId = taskId;
    }
    public String getTaskCode() {
        return taskCode;
    }

    public void setTaskCode(String taskCode) {
        this.taskCode = taskCode;
    }
    public Date getSatrtTime() {
        return satrtTime;
    }

    public void setSatrtTime(Date satrtTime) {
        this.satrtTime = satrtTime;
    }
    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }
    public BigDecimal getDistributeCount() {
        return distributeCount;
    }

    public void setDistributeCount(BigDecimal distributeCount) {
        this.distributeCount = distributeCount;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public String getChangeState() {
        return changeState;
    }

    public void setChangeState(String changeState) {
        this.changeState = changeState;
    }
    public Long getProductId() {
        return productId;
    }

    public void setProductId(Long productId) {
        this.productId = productId;
    }
    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }
    public Long getCustomerManageId() {
        return customerManageId;
    }

    public void setCustomerManageId(Long customerManageId) {
        this.customerManageId = customerManageId;
    }
    public String getCustomerManageName() {
        return customerManageName;
    }

    public void setCustomerManageName(String customerManageName) {
        this.customerManageName = customerManageName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getWorksiteId() {
        return worksiteId;
    }

    public void setWorksiteId(Long worksiteId) {
        this.worksiteId = worksiteId;
    }
    public String getWorksiteName() {
        return worksiteName;
    }

    public void setWorksiteName(String worksiteName) {
        this.worksiteName = worksiteName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public BigDecimal getQuantity() {
        return quantity;
    }

    public void setQuantity(BigDecimal quantity) {
        this.quantity = quantity;
    }
    public BigDecimal getWeighNumber() {
        return weighNumber;
    }

    public void setWeighNumber(BigDecimal weighNumber) {
        this.weighNumber = weighNumber;
    }
    public BigDecimal getNotWeighNumber() {
        return notWeighNumber;
    }

    public void setNotWeighNumber(BigDecimal notWeighNumber) {
        this.notWeighNumber = notWeighNumber;
    }

    public BigDecimal getAddCount() {
        return addCount;
    }

    public void setAddCount(BigDecimal addCount) {
        this.addCount = addCount;
    }

    public BigDecimal getAddedCount() {
        return addedCount;
    }

    public void setAddedCount(BigDecimal addedCount) {
        this.addedCount = addedCount;
    }

    public Integer getProductState() {
        return productState;
    }

    public void setProductState(Integer productState) {
        this.productState = productState;
    }

    public BigDecimal getNotDistributeCount() {
        return notDistributeCount;
    }

    public void setNotDistributeCount(BigDecimal notDistributeCount) {
        this.notDistributeCount = notDistributeCount;
    }

    public BigDecimal getDistributedCount() {
        return distributedCount;
    }

    public void setDistributedCount(BigDecimal distributedCount) {
        this.distributedCount = distributedCount;
    }

    public Integer getIsDistributeCar() {
        return isDistributeCar;
    }

    public void setIsDistributeCar(Integer isDistributeCar) {
        this.isDistributeCar = isDistributeCar;
    }

    public Integer getSort() {
        return sort;
    }

    public void setSort(Integer sort) {
        this.sort = sort;
    }

    public BigDecimal getProductedCount() {
        return productedCount;
    }

    public void setProductedCount(BigDecimal productedCount) {
        this.productedCount = productedCount;
    }

    public BigDecimal getNotProductCount() {
        return notProductCount;
    }

    public void setNotProductCount(BigDecimal notProductCount) {
        this.notProductCount = notProductCount;
    }

    public List<ProductiontasktransportEntity> getTaskTransportList() {
        return taskTransportList;
    }

    public void setTaskTransportList(List<ProductiontasktransportEntity> taskTransportList) {
        this.taskTransportList = taskTransportList;
    }
}

==> ejc-production-impl-3.0.0-20220621.073019-165-sources.jar: com/ejianc/business/production/bean/UnitdistributionEntity.java <==
package com.ejianc.business.production.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 分配机组
 * 
 * @author generator
 * 
 */
 @TableName("ejc_production_unit_distribution")
public class UnitdistributionEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="unit_id")
    private Long unitId; // 机组id
    @TableField(value="unit_name")
    private String unitName; // 机组名称
    @TableField(value="task_id")
    private Long taskId; // 任务单id
    @TableField(value="task_code")
    private String taskCode; // 任务单单号
    @TableField(value="satrt_time")
    private Date satrtTime; // 开始时间
    @TableField(value="end_time")
    private Date endTime; // 结束时间
    @TableField(value="task_time")
    private Date taskTime; // 生产任务单日期
    @TableField(value="distribute_count")
    private BigDecimal distributeCount; // 分配数量
    @TableField(value="operator_id")
    private Long operatorId; // 经办人id
    @TableField(value="operator_name")
    private String operatorName; // 经办人名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="change_id")
    private Long changeId; // 变更单据id
    @TableField(value="change_state")
    private String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    @TableField(value="product_id")
    private Long productId; // 产品id
    @TableField(value="product_name")
    private String productName; // 产品名称
    @TableField(value="customer_manage_id")
    private Long customerManageId; // 客户管理档案id
    @TableField(value="customer_manage_name")
    private String customerManageName; // 客户管理档案名称
    @TableField(value="project_id")
    private Long projectId; // 工程id
    @TableField(value="project_name")
    private String projectName; // 工程名称
    @TableField(value="worksite_id")
    private Long worksiteId; // 工地id
    @TableField(value="worksite_name")
    private String worksiteName; // 工地名称
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="quantity")
    private BigDecimal quantity; // 数量
    @TableField(value="weigh_number")
    private BigDecimal weighNumber; // 过磅数
    @TableField(value="not_weigh_number")
    private BigDecimal notWeighNumber; // 未过磅数量
    @TableField(value="add_count")
    private BigDecimal addCount; // 追加数量
    @TableField(value="added_count")
    private BigDecimal addedCount; // 追加后数量
    @TableField(value="product_state")
    private Integer productState; // 分配机组生产状态 ：1 生产中 2 生产完成
    @TableField(value="not_distribute_count")
    private BigDecimal notDistributeCount; // 未分配数量
    @TableField(value="distributed_count")
    private BigDecimal distributedCount; // 已分配数量
    @TableField(value="is_distribute_car")
    private Integer isDistributeCar; // 分配车辆状态 ：1 未分配 2 已分配
    @TableField(value="sort")
    private Integer sort; // 分配车辆状态 ：1 未分配 2 已分配
    @TableField(value="producted_count")
    private BigDecimal productedCount; // 已生产数量
    @TableField(value="not_product_count")
    private BigDecimal notProductCount; // 未生产数量

    @TableField(exist=false)
    @SubEntity(serviceName="productiontasktransportService",pidName = "unitdistributeId")
    private List<ProductiontasktransportEntity> taskTransportList = new ArrayList<>(); // 运费维护子表
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public Long getTaskId() {
        return taskId;
    }

    public void setTaskId(Long taskId) {
        this.taskId = taskId;
    }
    public String getTaskCode() {
        return taskCode;
    }

    public void setTaskCode(String taskCode) {
        this.taskCode = taskCode;
    }
    public Date getSatrtTime() {
        return satrtTime;
    }

    public void setSatrtTime(Date satrtTime) {
        this.satrtTime = satrtTime;
    }
    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }
    public BigDecimal getDistributeCount() {
        return distributeCount;
    }

    public void setDistributeCount(BigDecimal distributeCount) {
        this.distributeCount = distributeCount;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public String getChangeState() {
        return changeState;
    }

    public void setChangeState(String changeState) {
        this.changeState = changeState;
    }
    public Long getProductId() {
        return productId;
    }

    public void setProductId(Long productId) {
        this.productId = productId;
    }
    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }
    public Long getCustomerManageId() {
        return customerManageId;
    }

    public void setCustomerManageId(Long customerManageId) {
        this.customerManageId = customerManageId;
    }
    public String getCustomerManageName() {
        return customerManageName;
    }

    public void setCustomerManageName(String customerManageName) {
        this.customerManageName = customerManageName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getWorksiteId() {
        return worksiteId;
    }

    public void setWorksiteId(Long worksiteId) {
        this.worksiteId = worksiteId;
    }
    public String getWorksiteName() {
        return worksiteName;
    }

    public void setWorksiteName(String worksiteName) {
        this.worksiteName = worksiteName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public BigDecimal getQuantity() {
        return quantity;
    }

    public void setQuantity(BigDecimal quantity) {
        this.quantity = quantity;
    }
    public BigDecimal getWeighNumber() {
        return weighNumber;
    }

    public void setWeighNumber(BigDecimal weighNumber) {
        this.weighNumber = weighNumber;
    }
    public BigDecimal getNotWeighNumber() {
        return notWeighNumber;
    }

    public void setNotWeighNumber(BigDecimal notWeighNumber) {
        this.notWeighNumber = notWeighNumber;
    }

    public BigDecimal getAddCount() {
        return addCount;
    }

    public void setAddCount(BigDecimal addCount) {
        this.addCount = addCount;
    }

    public BigDecimal getAddedCount() {
        return addedCount;
    }

    public void setAddedCount(BigDecimal addedCount) {
        this.addedCount = addedCount;
    }

    public Integer getProductState() {
        return productState;
    }

    public void setProductState(Integer productState) {
        this.productState = productState;
    }

    public BigDecimal getNotDistributeCount() {
        return notDistributeCount;
    }

    public void setNotDistributeCount(BigDecimal notDistributeCount) {
        this.notDistributeCount = notDistributeCount;
    }

    public BigDecimal getDistributedCount() {
        return distributedCount;
    }

    public void setDistributedCount(BigDecimal distributedCount) {
        this.distributedCount = distributedCount;
    }

    public Integer getIsDistributeCar() {
        return isDistributeCar;
    }

    public void setIsDistributeCar(Integer isDistributeCar) {
        this.isDistributeCar = isDistributeCar;
    }

    public Integer getSort() {
        return sort;
    }

    public void setSort(Integer sort) {
        this.sort = sort;
    }

    public BigDecimal getProductedCount() {
        return productedCount;
    }

    public void setProductedCount(BigDecimal productedCount) {
        this.productedCount = productedCount;
    }

    public BigDecimal getNotProductCount() {
        return notProductCount;
    }

    public void setNotProductCount(BigDecimal notProductCount) {
        this.notProductCount = notProductCount;
    }

    public List<ProductiontasktransportEntity> getTaskTransportList() {
        return taskTransportList;
    }

    public void setTaskTransportList(List<ProductiontasktransportEntity> taskTransportList) {
        this.taskTransportList = taskTransportList;
    }

    public Date getTaskTime() {
        return taskTime;
    }

    public void setTaskTime(Date taskTime) {
        this.taskTime = taskTime;
    }
}
